/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { SeparatorOrientation } from './separator-orientation';
import * as i0 from "@angular/core";
/**
 * Specifies a separator in the content of the [Inputs]({% slug adornments_textbox %}#toc-separator) and [DropDowns]({% slug adornments_multiselect %}#toc-separator).
 * @example
 * ```ts-no-run
 * _@Component({
 * selector: 'my-app',
 * template: `
 *  <kendo-textbox>
 *      <ng-template kendoSuffixTemplate>
 *          <button kendoButton look="clear" icon="image"></button>
 *          <kendo-separator></kendo-separator>
 *          <button kendoButton look="clear" icon="image"></button>
 *      </ng-template>
 *  </kendo-textbox>
 * `
 * })
 * class AppComponent {}
 * ```
 */
export declare class SeparatorComponent {
    /**
     * Specifies the orientation of the separator. Applicable for the adornments of the [`TextAreaComponent`](slug:api_inputs_textareacomponent).
     *
     * @default 'vertical'
     */
    orientation: SeparatorOrientation;
    /**
     * @hidden
     */
    get vertical(): boolean;
    /**
     * @hidden
     */
    get horizontal(): boolean;
    /**
     * @hidden
     */
    hostClass: boolean;
    static ɵfac: i0.ɵɵFactoryDeclaration<SeparatorComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<SeparatorComponent, "kendo-separator", never, { "orientation": { "alias": "orientation"; "required": false; }; }, {}, never, never, true, never>;
}
