/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { ElementRef, NgZone, Renderer2, SimpleChanges } from "@angular/core";
import { MultiTabStop } from "./toggle-button-tab-stop";
import * as i0 from "@angular/core";
/**
 * Includes the button that toggles the Popup in the tab sequence when applied
 * to a SplitButton, ComboBox, MultiComboBox, DatePicker, TimePicker, and DateTimePicker component.
 * ```ts-no-run
 * _@Component({
 * selector: 'my-app',
 * template: `
 *  <kendo-combobox [data]="data"
 *      kendoToggleButtonTabStop>
 *  </kendo-combobox>
 *
 *  <kendo-datepicker [(ngModel)]="value"
 *      kendoToggleButtonTabStop>
 *  </kendo-datepicker>
 * `
 * })
 * class AppComponent {}
 * ```
 */
export declare class ToggleButtonTabStopDirective {
    private hostEl;
    private renderer;
    private zone;
    private hostComponent;
    /**
     * @hidden
     *
     * Allows setting the interactive state of the toggle button.
     *
     * @default true
     */
    active: any;
    /**
     * Defines the value of the `aria-label` attribute of the toggle button when active.
     *
     * @default "toggle popup"
     */
    toggleButtonAriaLabel: string;
    private button;
    private sub;
    private focusButton;
    private isSplitButton;
    private observer;
    /**
     * @hidden
     */
    constructor(hostEl: ElementRef, renderer: Renderer2, zone: NgZone, hostComponent: MultiTabStop);
    ngOnInit(): void;
    ngAfterViewInit(): void;
    ngOnChanges(changes: SimpleChanges): void;
    ngOnDestroy(): void;
    private activateButton;
    private deactivateButton;
    private onFocus;
    private onBlur;
    private onClick;
    private onKeyDown;
    private addListeners;
    private removeListeners;
    private focusToggleButton;
    private returnFocusToToggleButton;
    private initializeObserver;
    static ɵfac: i0.ɵɵFactoryDeclaration<ToggleButtonTabStopDirective, never>;
    static ɵdir: i0.ɵɵDirectiveDeclaration<ToggleButtonTabStopDirective, "[kendoToggleButtonTabStop]", never, { "active": { "alias": "kendoToggleButtonTabStop"; "required": false; }; "toggleButtonAriaLabel": { "alias": "toggleButtonAriaLabel"; "required": false; }; }, {}, never, never, true, never>;
}
